server/serverconfig.py
changeset 7398 26695dd703d8
parent 7301 93e96700e0c0
child 7896 4c954e1e73ef
--- a/server/serverconfig.py	Thu May 19 10:36:26 2011 +0200
+++ b/server/serverconfig.py	Thu May 19 10:53:11 2011 +0200
@@ -130,7 +130,7 @@
         ('connections-pool-size',
          {'type' : 'int',
           'default': 4,
-          'help': 'size of the connections pools. Each source supporting multiple \
+          'help': 'size of the connections pool. Each source supporting multiple \
 connections will have this number of opened connections.',
           'group': 'main', 'level': 3,
           }),
@@ -209,9 +209,9 @@
           }),
         ) + CubicWebConfiguration.options)
 
-    # should we open connections pools (eg connect to sources). This is usually
-    # necessary...
-    open_connections_pools = True
+    # should we init the connections pool (eg connect to sources). This is
+    # usually necessary...
+    init_cnxset_pool = True
 
     # read the schema from the database
     read_instance_schema = True